from __future__ import absolute_import as _

import _cffi_backend as _

from .read import read_plink
from .testit import test

__name__ = "pandas-plink"
__version__ = "1.2.18"
__author__ = "Danilo Horta"
__author_email__ = "horta@ebi.ac.uk"


def example_file_prefix():
    r"""Data files prefix."""
    import os
    p = __import__('pandas_plink').__path__[0]
    return os.path.join(p, 'test', 'data_files', 'data')


__all__ = [
    "__name__", "__version__", "__author__", "__author_email__", "test",
    'example_file_prefix', 'read_plink'
]



from os.path import dirname, join, realpath

from cffi import FFI

ffibuilder = FFI()
ffibuilder.set_unicode(False)

ffibuilder.cdef(r"""
    int read_bed_chunk(char*, uint64_t, uint64_t,
                       uint64_t, uint64_t,
                       uint64_t, uint64_t,
                       uint64_t*, uint64_t*);
""")

dirname(realpath(__file__))
ffibuilder.set_source(
    "pandas_plink.bed_reader",
    "",
    sources=[join('pandas_plink', '_bed_reader.c')])

if __name__ == "__main__":
    ffibuilder.compile(verbose=True)
